/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.configuration.internal;

import javax.inject.Named;

import org.junit.jupiter.api.Test;
import org.mockito.InOrder;
import org.xwiki.configuration.ConfigurationSource;
import org.xwiki.test.junit5.mockito.ComponentTest;
import org.xwiki.test.junit5.mockito.InjectMockComponents;
import org.xwiki.test.junit5.mockito.MockComponent;

import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.mockito.Mockito.*;

/**
 * Unit tests for {@link DefaultConfigurationSource}.
 *
 * @version $Id: 11b983c0c6960c0ba29c139a10c2b75e03d6d6a2 $
 * @since 6.1M2
 */
@ComponentTest
class DefaultConfigurationSourceTest
{
    @InjectMockComponents
    private DefaultConfigurationSource source;

    @MockComponent
    @Named("documents")
    private ConfigurationSource documentsSource;

    @MockComponent
    @Named("xwikiproperties")
    private ConfigurationSource xwikiPropertiesSource;

    @Test
    void containsKey()
    {
        when(this.documentsSource.containsKey("key")).thenReturn(false);
        when(this.xwikiPropertiesSource.containsKey("key")).thenReturn(true);

        assertTrue(this.source.containsKey("key"));

        // Verify that the call order is correct
        InOrder inOrder = inOrder(xwikiPropertiesSource, this.documentsSource);
        // First call
        inOrder.verify(this.documentsSource).containsKey("key");
        // Second call
        inOrder.verify(xwikiPropertiesSource).containsKey("key");
    }
}
