/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.csrf;

import org.mockito.ArgumentMatcher;
import org.mockito.invocation.InvocationOnMock;
import org.mockito.stubbing.Answer;

/**
 * A matcher that acts as an action and returns the matched argument in the mocked method, allowing small modifications
 * (prepend/append something to the value).
 * 
 * @version $Id: a285757a342efde2fb4fa30a15675157d73c0f50 $
 * @since 2.5M2
 */
public final class CopyStringMatcher implements ArgumentMatcher<String>, Answer<String>
{
    /** The string to copy. */
    private String value = null;

    /** String to prepend to the copied value. */
    private String prefix;

    /** String to append to the copied value. */
    private String suffix;

    /**
     * Create new CopyStringMatcher with the given prefix and suffix.
     * 
     * @param prefix string to prepend to the value
     * @param suffix string to append to the value
     */
    public CopyStringMatcher(String prefix, String suffix)
    {
        this.prefix = prefix;
        this.suffix = suffix;
    }

    @Override
    public boolean matches(String argument)
    {
        if (argument.startsWith(this.prefix) && argument.endsWith(suffix)) {
            this.value = argument;
            return true;
        }
        return false;
    }

    @Override
    public String answer(InvocationOnMock invocationOnMock) throws Throwable
    {
        if (this.value == null) {
            return this.prefix + this.suffix;
        }
        return this.prefix + this.value + this.suffix;
    }
}
