/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.mail.internal;

import javax.inject.Singleton;
import javax.mail.internet.InternetAddress;

import org.xwiki.component.annotation.Component;
import org.xwiki.mail.EmailAddressObfuscator;

/**
 * Default email address obfuscator replacing {@code john@doe.com} with {@code j...@doe.com}.
 *
 * @version $Id: 169079cb6f82e03dca7b94dcecc181d32e4eda26 $
 * @since 12.4RC1
 */
@Component
@Singleton
public class DefaultEmailAddressObfuscator implements EmailAddressObfuscator
{
    @Override
    public String obfuscate(InternetAddress emailAddress)
    {
        return emailAddress.toString().replaceAll("^(.).*@", "$1...@");
    }
}
