/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.mentions.internal.rendering;

import java.util.Collections;
import java.util.List;

import javax.inject.Named;
import javax.inject.Provider;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.syntax.Syntax;
import org.xwiki.rendering.syntax.SyntaxType;

/**
 * Register the {@code plainmentions/1.0} Syntax supported by this module.
 *
 * @version $Id: dbba9803f170c0464eb76f8df7aa75e215847945 $
 * @since 14.0RC1
 */
@Component
@Named("plainmentions/1.0")
@Singleton
public class MentionsSyntaxProvider implements Provider<List<Syntax>>
{
    /**
     * Plain Mentions syntax.
     */
    public static final SyntaxType PLAINMENTIONS = new SyntaxType("plainmentions", "Plain Text Mentions");

    /**
     * Plain Mentions 1.0 syntax.
     */
    public static final Syntax PLAINMENTIONS_1_0 = new Syntax(PLAINMENTIONS, "1.0");

    @Override
    public List<Syntax> get()
    {
        return Collections.singletonList(PLAINMENTIONS_1_0);
    }
}
