/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.model.internal.reference;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.model.EntityType;
import org.xwiki.model.reference.EntityReferenceResolver;
import org.xwiki.model.reference.PageObjectPropertyReference;
import org.xwiki.model.reference.PageObjectPropertyReferenceResolver;

/**
 * Specialized version of {@link org.xwiki.model.reference.EntityReferenceResolver} which can be considered a helper
 * component to resolve {@link PageObjectPropertyReference} objects from their string representation. This
 * implementation uses fixed default values when parts of the Reference are missing in the string representation.
 * Default values are retrieved from the {@link org.xwiki.model.ModelConfiguration} class.
 * 
 * @version $Id: 6666ed56b5f84dbd3c0571daa62c6409f77f71e6 $
 * @since 10.6RC1
 */
@Component
@Singleton
public class DefaultStringPageObjectPropertyReferenceResolver implements PageObjectPropertyReferenceResolver<String>
{
    /**
     * The default entity resolver, used to delegate actual resolving of string representations.
     */
    @Inject
    private EntityReferenceResolver<String> entityReferenceResolver;

    @Override
    public PageObjectPropertyReference resolve(String propertyReferenceRepresentation, Object... parameters)
    {
        return new PageObjectPropertyReference(this.entityReferenceResolver.resolve(propertyReferenceRepresentation,
            EntityType.PAGE_OBJECT_PROPERTY, parameters));
    }
}
