/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.officeimporter.internal.converter;

import java.util.List;

import org.jodconverter.core.document.DocumentFormat;
import org.xwiki.officeimporter.converter.OfficeDocumentFormat;

/**
 * Default implementation for {@link OfficeDocumentFormat} based on Jodconverter's {@link DocumentFormat}.
 *
 * @version $Id: d3911b303f75b435b56e10e9b404f3998fbf5766 $
 * @since 13.1RC1
 */
public class DefaultOfficeDocumentFormat implements OfficeDocumentFormat
{
    private DocumentFormat documentFormat;

    /**
     * Default constructor.
     *
     * @param documentFormat Jodconverter's format.
     */
    public DefaultOfficeDocumentFormat(DocumentFormat documentFormat)
    {
        this.documentFormat = documentFormat;
    }

    @Override
    public String getName()
    {
        return this.documentFormat.getName();
    }

    @Override
    public String getMediaType()
    {
        return this.documentFormat.getMediaType();
    }

    @Override
    public List<String> getExtensions()
    {
        return this.documentFormat.getExtensions();
    }

    @Override
    public String getExtension()
    {
        return this.documentFormat.getExtension();
    }
}
