/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package com.xpn.xwiki.internal.fileupload;

import java.util.Iterator;

import javax.servlet.http.Part;

import org.apache.commons.fileupload.FileItemHeaders;

/**
 * Implement a {@link FileItemHeaders} based on a {@link Part}.
 * 
 * @version $Id: c9fd76c569877d7a352b3d44694d21f63f9ed9e5 $
 * @since 13.0
 */
public class PartFileItemHeaders implements FileItemHeaders
{
    private final Part part;

    /**
     * @param part the servlet part
     */
    public PartFileItemHeaders(Part part)
    {
        this.part = part;
    }

    @Override
    public String getHeader(String name)
    {
        return this.part.getHeader(name);
    }

    @Override
    public Iterator<String> getHeaders(String name)
    {
        return this.part.getHeaders(name).iterator();
    }

    @Override
    public Iterator<String> getHeaderNames()
    {
        return this.part.getHeaderNames().iterator();
    }

}
