/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.ratings.internal;

import java.util.Arrays;

import org.junit.jupiter.api.Test;
import org.xwiki.model.reference.DocumentReference;
import org.xwiki.ratings.RatingsManager;
import org.xwiki.ratings.RatingsManagerFactory;
import org.xwiki.refactoring.event.DocumentRenamedEvent;
import org.xwiki.test.junit5.mockito.ComponentTest;
import org.xwiki.test.junit5.mockito.InjectMockComponents;
import org.xwiki.test.junit5.mockito.MockComponent;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

/**
 * Tests for {@link RatingMovedEntityListener}.
 *
 * @version $Id: ba3a0f5c063103ff5b5e4a3c0a1d0da639f123af $
 * @since 12.10
 */
@ComponentTest
public class RatingMovedEntityListenerTest
{
    @InjectMockComponents
    private RatingMovedEntityListener listener;

    @MockComponent
    private RatingsManagerFactory ratingsManagerFactory;

    @Test
    void onDocumentRenamedEvent() throws Exception
    {
        RatingsManager manager1 = mock(RatingsManager.class);
        RatingsManager manager2 = mock(RatingsManager.class);
        when(ratingsManagerFactory.getInstantiatedManagers()).thenReturn(Arrays.asList(manager1, manager2));

        DocumentRenamedEvent documentRenamedEvent = mock(DocumentRenamedEvent.class);
        DocumentReference oldReference = mock(DocumentReference.class);
        DocumentReference newReference = mock(DocumentReference.class);
        when(documentRenamedEvent.getSourceReference()).thenReturn(oldReference);
        when(documentRenamedEvent.getTargetReference()).thenReturn(newReference);

        this.listener.onEvent(documentRenamedEvent, null, null);
        verify(manager1).moveRatings(oldReference, newReference);
        verify(manager2).moveRatings(oldReference, newReference);
    }
}
