/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.macro.cache;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.platform.security.requiredrights.MacroRequiredRightsAnalyzer;
import org.xwiki.platform.security.requiredrights.MacroRequiredRightReporter;
import org.xwiki.rendering.block.MacroBlock;

/**
 * Analyzes required rights for the cache macro.
 * <p>
 * This ensures that the content of the id parameter is considered.
 * </p>
 * @version $Id: 725f03eeb2b84779e8cc0ca324d1b76c55e8fda5 $
 * @since 15.10RC1
 */
@Component
@Singleton
@Named("cache")
public class CacheMacroRequiredRightsAnalyzer implements MacroRequiredRightsAnalyzer
{
    @Override
    public void analyze(MacroBlock macroBlock, MacroRequiredRightReporter reporter)
    {
        reporter.analyzeContent(macroBlock, macroBlock.getParameter("id"));
        reporter.analyzeContent(macroBlock, macroBlock.getContent());
    }
}
