/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.resource.temporary;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import org.xwiki.component.annotation.Role;

/**
 * Interface used to read and write temporary resources.
 * 
 * @version $Id: 7c7af9bccda440692c15b6dd0686a61459cfcb3e $
 * @since 7.4.6
 * @since 8.2.2
 * @since 8.3
 */
@Role
public interface TemporaryResourceStore
{
    /**
     * Create a new temporary file with the specified content.
     * 
     * @param reference the temporary resource reference
     * @param content the content of the temporary file
     * @return the created temporary file
     * @throws IOException if creating the temporary file fails
     */
    File createTemporaryFile(TemporaryResourceReference reference, InputStream content) throws IOException;

    /**
     * Get the temporary file associated to the specified resource reference.
     * 
     * @param reference the temporary resource reference
     * @return the temporary file associated to the specified resource reference
     * @throws IOException if the resource path is invalid
     */
    File getTemporaryFile(TemporaryResourceReference reference) throws IOException;
}
