/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.security.internal;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.configuration.ConfigurationSource;
import org.xwiki.security.SecurityConfiguration;

/**
 * Default configuration implementation taking its values from {@code xwiki.properties}.
 *
 * @version $Id: ef5964c64968ab48caa7e967bc8efa353d69892a $
 * @since 13.10RC1
 */
@Component
@Singleton
public class DefaultSecurityConfiguration extends AbstractSecurityConfiguration implements SecurityConfiguration
{
    /**
     * Prefix for query items limit configuration.
     */
    private static final String QUERY_ITEMS_LIMIT = AbstractSecurityConfiguration.SECURITY + ".queryItemsLimit";

    /**
     * Default query items limit is set to 100 because it corresponds to the LiveTable/LiveData max items view limit.
     */
    private static final int DEFAULT_QUERY_ITEMS_LIMIT = 100;

    /**
     * Obtain configuration from the {@code xwiki.properties} file. We currently consider that this is a technical
     * configuration that can only be changed by restarting XWiki.
     */
    @Inject
    @Named("xwikiproperties")
    private ConfigurationSource configuration;

    @Override
    public int getQueryItemsLimit()
    {
        return this.configuration.getProperty(QUERY_ITEMS_LIMIT, DEFAULT_QUERY_ITEMS_LIMIT);
    }
}
