/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.security.authentication;

import org.xwiki.observation.event.Event;
import org.xwiki.user.UserReference;

/**
 * This event is triggered every time a user is authenticated.
 *
 * @version $Id: 1e91ada491deaf688f0ea063a84dc45837eece95 $
 * @since 13.3RC1
 */
public class UserAuthenticatedEvent implements Event
{
    /**
     * The reference related to an authenticated user for whom a {@link UserAuthenticatedEvent} has been triggered.
     */
    private final UserReference userReference;

    /**
     * This event will match only events of the same type affecting the same user.
     *
     * @param userReference The reference related to an authenticated user for whom a {@link UserAuthenticatedEvent}
     * has been triggered.
     */
    public UserAuthenticatedEvent(UserReference userReference)
    {
        this.userReference = userReference;
    }

    /**
     * @return the {@link UserReference} of the authenticated user.
     */
    public UserReference getUserReference()
    {
        return this.userReference;
    }

    @Override
    public boolean matches(Object other)
    {
        return other instanceof UserAuthenticatedEvent;
    }

}

