/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.security.notifications;

import java.util.Set;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.xwiki.eventstream.TargetableEvent;

/**
 * Targetable event aimed at admins, to inform them of the presence of new security vulnerabilities.
 *
 * @version $Id: 229de7d1a1baab0de4de9b403e12ef1a32b0dc5a $
 * @since 15.5RC1
 */
public class NewExtensionSecurityVulnerabilityTargetableEvent implements TargetableEvent
{
    private final Set<String> target;

    /**
     * Default constructor.
     *
     * @param target the target of the event
     */
    public NewExtensionSecurityVulnerabilityTargetableEvent(Set<String> target)
    {
        this.target = target;
    }

    @Override
    public boolean matches(Object otherEvent)
    {
        return otherEvent instanceof NewExtensionSecurityVulnerabilityTargetableEvent;
    }

    @Override
    public Set<String> getTarget()
    {
        return this.target;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o) {
            return true;
        }

        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        NewExtensionSecurityVulnerabilityTargetableEvent that = (NewExtensionSecurityVulnerabilityTargetableEvent) o;

        return new EqualsBuilder()
            .append(this.target, that.target)
            .isEquals();
    }

    @Override
    public int hashCode()
    {
        return new HashCodeBuilder(17, 37)
            .append(this.target)
            .toHashCode();
    }
}
