/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.security.notifications.internal;

import java.util.List;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.eventstream.Event;
import org.xwiki.eventstream.RecordableEvent;
import org.xwiki.eventstream.RecordableEventConverter;
import org.xwiki.eventstream.RecordableEventDescriptor;
import org.xwiki.extension.security.notifications.NewExtensionSecurityVulnerabilityTargetableEvent;
import org.xwiki.extension.security.notifications.NewExtensionSecurityVulnerabilityTargetableEventDescriptor;

/**
 * Recordable event converter for the {@link NewExtensionSecurityVulnerabilityTargetableEvent} events.
 *
 * @version $Id: e15955323745a4accee7406f245952941961b1cb $
 * @since 15.5
 */
@Component
@Singleton
@Named("extensionSecurityVulnerability")
public class NewExtensionSecurityVulnerabilityRecordableEventConverter implements RecordableEventConverter
{
    @Inject
    private RecordableEventConverter defaultRecordableEventConverter;

    @Inject
    @Named(NewExtensionSecurityVulnerabilityTargetableEventDescriptor.TYPE)
    private RecordableEventDescriptor recordableEventDescriptor;

    @Override
    public Event convert(RecordableEvent recordableEvent, String source, Object data) throws Exception
    {
        Event event = this.defaultRecordableEventConverter.convert(recordableEvent, source, data);
        event.setTitle(this.recordableEventDescriptor.getApplicationName());
        return event;
    }

    @Override
    public List<RecordableEvent> getSupportedEvents()
    {
        return List.of(new NewExtensionSecurityVulnerabilityTargetableEvent(null));
    }
}
